@@ -1,9 +1,10 @@
 package CPAN::Releases::Latest::ReleaseIterator;
-$CPAN::Releases::Latest::ReleaseIterator::VERSION = '0.05_01';
+$CPAN::Releases::Latest::ReleaseIterator::VERSION = '0.01';
 use 5.006;
 use Moo;
 use CPAN::Releases::Latest;
 use CPAN::Releases::Latest::Release;
+use autodie;
 
 has 'latest' =>
     (
@@ -19,7 +20,8 @@ sub next_release
     my $fh;
 
     if (not defined($fh = $self->_fh)) {
-        $fh = $self->latest->_open_file();
+        open($fh, '<', $self->latest->path // $self->latest->cache_path);
+        my $header = <$fh>;
         $self->_fh($fh);
     }
 
